@@ -1,4 +1,4 @@
-from pro_craft.prompt_helper import Intel,IntellectType
+from pro_craft import Intel
 from pro_craft.log import Log
 from pro_craft.utils import extract_
 from typing import List, Dict, Any
