@@ -2,9 +2,8 @@
 from db_help.qdrant import QdrantManager
 from pydantic import BaseModel
 from datetime import datetime
-from pro_craft.utils import get_adler32_hash, embedding_inputs
-from pro_craft.prompt_helper import Intel, IntellectType
-from pro_craft.utils import extract_
+from pro_craft.utils import get_adler32_hash, embedding_inputs,extract_
+from pro_craft import Intel
 from enum import Enum
 import json
 
