@@ -1,6 +1,6 @@
 # 测试1
 from pro_craft.utils import extract_
-from pro_craft.log import Log
+from pro_craft import logger as pro_craft_logger
 from llmada.core import BianXieAdapter, ArkAdapter
 from datetime import datetime
 from enum import Enum
@@ -68,9 +68,10 @@ class AsyncIntel():
     def __init__(self,
                  database_url = "",
                  model_name = "",
+                 logger = None,
                 ):
         database_url = database_url or os.getenv("database_url")
-        self.logger = logger or Log.logger
+        self.logger = logger or pro_craft_logger
         try:
             assert database_url
             assert 'aio' in database_url
