@@ -1,7 +1,7 @@
 # 测试1
 
 from pro_craft.utils import extract_
-from pro_craft.log import Log
+from pro_craft import logger as pro_craft_logger
 from pro_craft.database import Prompt, UseCase, PromptBase
 from pro_craft.utils import create_session, create_async_session
 from llmada.core import BianXieAdapter, ArkAdapter
@@ -88,7 +88,7 @@ class IntelNew():
         else:
             print('Use BianXieAdapter')
             self.llm = BianXieAdapter()
-        self.logger = logger or Log.logger
+        self.logger = logger or pro_craft_logger
         
     def _get_latest_prompt_version(self,target_prompt_id,session):
         """
